@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-document.c,v 1.131 2006/04/20 17:01:13 paolo Exp $
+ * $Id: gedit-document.c,v 1.132 2006/05/18 22:55:16 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -62,7 +62,7 @@
 #define PROFILE(x)
 #endif
 
-PROFILE (static GTimer *timer = NULL);
+PROFILE (static GTimer *timer = NULL)
 
 #ifdef MAXPATHLEN
 #define GEDIT_MAX_PATH_LEN  MAXPATHLEN
@@ -1212,7 +1212,7 @@ gedit_document_insert_file (GeditDocument       *doc,
 	g_return_val_if_fail (gtk_text_iter_get_buffer (iter) == 
 				GTK_TEXT_BUFFER (doc), FALSE);
 
-	// TODO
+	/* TODO */
 
 	return FALSE;
 }
