@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-panel.c,v 1.6.2.4 2006/06/15 15:03:43 sfre Exp $
+ * $Id: gedit-panel.c,v 1.7 2006/04/25 17:47:53 sfre Exp $
  */
 
 #include "gedit-panel.h"
@@ -422,45 +422,21 @@ gedit_panel_init (GeditPanel *panel)
 	gtk_object_sink (GTK_OBJECT (panel->priv->tooltips));
 }
 
-static void
-button_style_set_cb (GtkWidget *button,
-		     GtkStyle *previous_style,
-		     gpointer user_data)
-{
-	gint h, w;
-
-	gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (button),
-					   GTK_ICON_SIZE_MENU, &w, &h);
-
-	gtk_widget_set_size_request (button, w + 2, h + 2);
-}
-
 static GtkWidget *
 create_small_button (GtkWidget *image)
 {
-	GtkWidget *button;
-	GtkRcStyle *rcstyle;
-	
-	button = gtk_button_new ();
-	gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
-
-	/* don't allow focus on the close button */
-	gtk_button_set_focus_on_click (GTK_BUTTON (button), FALSE);
-
-	/* make it as small as possible */
-	rcstyle = gtk_rc_style_new ();
-	rcstyle->xthickness = rcstyle->ythickness = 0;
-	gtk_widget_modify_style (button, rcstyle);
-	gtk_rc_style_unref (rcstyle);
-
-	gtk_widget_show (image);
+	/* This is quite ugly and sometimes don't give good results */
+	gint w, h;
+	GtkWidget *button = gtk_button_new ();	
+	gtk_widget_show (image);		    
+	gtk_button_set_relief (GTK_BUTTON (button),
+			       GTK_RELIEF_NONE);
 
+	gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &w, &h);
+	gtk_widget_set_size_request (image, w, h); 
+	gtk_widget_set_size_request (button, w + 4, h + 4);
 	gtk_container_add (GTK_CONTAINER (button), image);
-
-	/* Set minimal size */
-	g_signal_connect (button, "style-set",
-			  G_CALLBACK (button_style_set_cb), NULL);
-
+	gtk_button_set_focus_on_click (GTK_BUTTON (button), FALSE);
 	return button;
 }
 
@@ -510,7 +486,7 @@ build_horizontal_panel (GeditPanel *panel)
 			    FALSE, 
 			    0);
 
-	image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
+	image = gtk_image_new_from_stock ("gtk-close", GTK_ICON_SIZE_MENU);
 	close_button = create_small_button (image);
 
 	gtk_box_pack_start (GTK_BOX (sidebar),
