@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window.c,v 1.20 2006/03/03 16:31:17 paolo Exp $
+ * $Id: gedit-window.c,v 1.27 2006/05/31 15:40:12 paolo Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -446,6 +446,57 @@ set_toolbar_style (GeditWindow *window,
 	return visible;
 }
 
+static void
+update_next_prev_doc_sensitivity (GeditWindow *window,
+				  GeditTab    *tab)
+{
+	gint	     tab_number;
+	GtkNotebook *notebook;
+	GtkAction   *action;
+	
+	gedit_debug (DEBUG_WINDOW);
+	
+	notebook = GTK_NOTEBOOK (_gedit_window_get_notebook (window));
+	
+	tab_number = gtk_notebook_page_num (notebook, GTK_WIDGET (tab));
+	g_return_if_fail (tab_number >= 0);
+	
+	action = gtk_action_group_get_action (window->priv->action_group,
+					      "DocumentsPreviousDocument");
+	gtk_action_set_sensitive (action, tab_number != 0);
+	
+	action = gtk_action_group_get_action (window->priv->action_group,
+					      "DocumentsNextDocument");
+	gtk_action_set_sensitive (action, 
+				  tab_number < gtk_notebook_get_n_pages (notebook) - 1);
+}
+
+static void
+update_next_prev_doc_sensitivity_per_window (GeditWindow *window)
+{
+	GeditTab  *tab;
+	GtkAction *action;
+	
+	gedit_debug (DEBUG_WINDOW);
+	
+	tab = gedit_window_get_active_tab (window);
+	if (tab != NULL)
+	{
+		update_next_prev_doc_sensitivity (window, tab);
+		
+		return;
+	}
+	
+	action = gtk_action_group_get_action (window->priv->action_group,
+					      "DocumentsPreviousDocument");
+	gtk_action_set_sensitive (action, FALSE);
+	
+	action = gtk_action_group_get_action (window->priv->action_group,
+					      "DocumentsNextDocument");
+	gtk_action_set_sensitive (action, FALSE);
+	
+}
+
 static void
 set_sensitivity_according_to_tab (GeditWindow *window,
 				  GeditTab    *tab)
@@ -575,6 +626,8 @@ set_sensitivity_according_to_tab (GeditWindow *window,
 				  (state != GEDIT_TAB_STATE_CLOSING) &&
 				  gedit_prefs_manager_get_enable_syntax_highlighting ());
 
+	update_next_prev_doc_sensitivity (window, tab);
+	
 	gedit_plugins_engine_update_plugins_ui (window, FALSE);
 }
 
@@ -694,7 +747,7 @@ create_language_menu_item (GtkSourceLanguage *lang,
 
 	/* add the action to the same radio group of the "Normal" action */
 	normal_action = gtk_action_group_get_action (window->priv->languages_action_group,
-						     "LangNormal");
+						     "LangNone");
 	group = gtk_radio_action_get_group (GTK_RADIO_ACTION (normal_action));
 	gtk_radio_action_set_group (action, group);
 
@@ -721,7 +774,7 @@ create_language_menu_item (GtkSourceLanguage *lang,
 static void
 create_languages_menu (GeditWindow *window)
 {
-	GtkRadioAction *action_normal;
+	GtkRadioAction *action_none;
 	const GSList *languages;
 	const GSList *l;
 	guint id;
@@ -729,18 +782,20 @@ create_languages_menu (GeditWindow *window)
 
 	gedit_debug (DEBUG_WINDOW);
 
-	/* add the "Normal" item before all the others */
-	action_normal = gtk_radio_action_new ("LangNormal",
-					      _("Normal"),
-					      _("Use Normal highlight mode"),
-					      NULL,
-					      -1);
+	/* add the "None" item before all the others */
+	
+	/* Translators: "None" means that no highlight mode is selected in the 
+	 * "View->Highlight Mode" submenu and so syntax highlighting is disabled */
+	action_none = gtk_radio_action_new ("LangNone", _("None"),
+					    _("Disable syntax highlighting"),
+					    NULL,
+					    -1);
 
 	gtk_action_group_add_action (window->priv->languages_action_group,
-				     GTK_ACTION (action_normal));
-	g_object_unref (action_normal);
+				     GTK_ACTION (action_none));
+	g_object_unref (action_none);
 
-	g_signal_connect (action_normal,
+	g_signal_connect (action_none,
 			  "activate",
 			  G_CALLBACK (language_toggled),
 			  window);
@@ -750,11 +805,11 @@ create_languages_menu (GeditWindow *window)
 	gtk_ui_manager_add_ui (window->priv->manager,
 			       id,
 			       "/MenuBar/ViewMenu/ViewHighlightModeMenu/LanguagesMenuPlaceholder",
-			       "LangNormal", "LangNormal",
+			       "LangNone", "LangNone",
 			       GTK_UI_MANAGER_MENUITEM,
 			       TRUE);
 
-	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action_normal), TRUE);
+	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action_none), TRUE);
 
 	/* now add all the known languages */
 	languages = gedit_languages_manager_get_available_languages_sorted (
@@ -786,7 +841,7 @@ update_languages_menu (GeditWindow *window)
 	if (lang != NULL)
 		lang_name = gtk_source_language_get_name (lang);
 	else
-		lang_name = g_strdup ("LangNormal");
+		lang_name = g_strdup ("LangNone");
 
 	escaped_lang_name = g_markup_escape_text (lang_name, -1);
 
@@ -822,7 +877,7 @@ open_recent_gtk (EggRecentViewGtk *view,
 		 EggRecentItem    *item,
 		 GeditWindow      *window)
 {
-	gedit_cmd_file_open_recent (item, window);
+	_gedit_cmd_file_open_recent (item, window);
 }
 
 static void
@@ -835,7 +890,7 @@ open_recent_uim (GtkAction   *action,
 						   action);
 	g_return_if_fail (item != NULL);
 
-	gedit_cmd_file_open_recent (item, window);
+	_gedit_cmd_file_open_recent (item, window);
 }
 
 #define TIP_MAX_URI_LEN 100
@@ -850,7 +905,7 @@ recent_tooltip_func_gtk (GtkTooltips   *tooltips,
 	gchar *uri_for_display;
 	gchar *trunc_uri;
 
-	uri_for_display = egg_recent_item_get_uri_for_display (item);
+	uri_for_display = gedit_utils_format_uri_for_display (egg_recent_item_peek_uri (item));
 	g_return_if_fail (uri_for_display != NULL);
 
 	trunc_uri = gedit_utils_str_middle_truncate (uri_for_display,
@@ -875,7 +930,7 @@ recent_tooltip_func_uim (EggRecentItem *item,
 	gchar *uri_for_display;
 	gchar *trunc_uri;
 
-	uri_for_display = egg_recent_item_get_uri_for_display (item);
+	uri_for_display = gedit_utils_format_uri_for_display (egg_recent_item_peek_uri (item));
 	g_return_val_if_fail (uri_for_display != NULL, NULL);
 
 	trunc_uri = gedit_utils_str_middle_truncate (uri_for_display,
@@ -1873,9 +1928,10 @@ drag_data_received_cb (GtkWidget        *widget,
 
 	uri_list = g_slist_reverse (uri_list);
 
-	gedit_cmd_load_files (GEDIT_WINDOW (target_window),
-			      uri_list,
-			      NULL);
+	gedit_commands_load_uris (GEDIT_WINDOW (target_window),
+				  uri_list,
+				  NULL,
+				  0);
 
 	g_slist_foreach (uri_list, (GFunc) g_free, NULL);	
 	g_slist_free (uri_list);
@@ -2211,7 +2267,7 @@ notebook_tab_added (GeditNotebook *notebook,
 			  window);
 
 	update_documents_list_menu (window);
-
+	
 	/* CHECK: it seems to me this does not work when tab are moved between
 	   windows */
 	/* Drag and drop support */
@@ -2306,10 +2362,6 @@ notebook_tab_removed (GeditNotebook *notebook,
 	g_return_if_fail (window->priv->num_tabs >= 0);
 	if (window->priv->num_tabs == 0)
 	{
-		GeditApp *app;
-			
-		app = gedit_app_get_default ();
-		
 		window->priv->active_tab = NULL;
 			       
 		set_title (window);
@@ -2327,11 +2379,15 @@ notebook_tab_removed (GeditNotebook *notebook,
 	if (!window->priv->removing_tabs)
 	{
 		update_documents_list_menu (window);
+		update_next_prev_doc_sensitivity_per_window (window);
 	}
 	else
 	{
 		if (window->priv->num_tabs == 0)
+		{
 			update_documents_list_menu (window);
+			update_next_prev_doc_sensitivity_per_window (window);
+		}
 	}
 
 	/* Set sensitivity */
@@ -2355,9 +2411,9 @@ notebook_tab_removed (GeditNotebook *notebook,
 		gtk_action_set_sensitive (action,
 					  FALSE);
 	}
-	
+
 	update_window_state (window);
-		
+
 	g_signal_emit (G_OBJECT (window), signals[TAB_REMOVED], 0, tab);	
 }
 
@@ -2366,6 +2422,7 @@ notebook_tabs_reordered (GeditNotebook *notebook,
 			 GeditWindow   *window)
 {
 	update_documents_list_menu (window);
+	update_next_prev_doc_sensitivity_per_window (window);
 	
 	g_signal_emit (G_OBJECT (window), signals[TABS_REORDERED], 0);
 }
@@ -2749,7 +2806,7 @@ gedit_window_init (GeditWindow *window)
 	window->priv->notebook = gedit_notebook_new ();
   	gtk_paned_pack1 (GTK_PANED (window->priv->vpaned), 
   			 window->priv->notebook,
-  			 FALSE, 
+  			 TRUE, 
   			 TRUE);
   	gtk_widget_show (window->priv->notebook);  			 
 
@@ -3152,26 +3209,32 @@ GList *
 gedit_window_get_unsaved_documents (GeditWindow *window)
 {
 	GList *unsaved_docs = NULL;
-	GList *docs;
+	GList *tabs;
 	GList *l;
 
 	g_return_val_if_fail (GEDIT_IS_WINDOW (window), NULL);
 	
-	docs = gedit_window_get_documents (window);
-
-	for (l = docs; l != NULL; l = l->next)
+	tabs = gtk_container_get_children (GTK_CONTAINER (window->priv->notebook));
+	
+	l = tabs;
+	while (l != NULL)
 	{
 		GeditTab *tab;
-		GeditDocument *doc;
-
-		doc = GEDIT_DOCUMENT (l->data);
-		tab = gedit_tab_get_from_document (doc);
 
+		tab = GEDIT_TAB (l->data);
+		
 		if (!_gedit_tab_can_close (tab))
+		{
+			GeditDocument *doc;
+			
+			doc = gedit_tab_get_document (tab);
 			unsaved_docs = g_list_prepend (unsaved_docs, doc);
+		}	
+		
+		l = g_list_next (l);
 	}
-
-	g_list_free (docs);
+	
+	g_list_free (tabs);
 
 	return g_list_reverse (unsaved_docs);
 }
@@ -3199,3 +3262,46 @@ _gedit_window_set_saving_session_state (GeditWindow *window,
 	}
 }
 
+GeditTab *
+gedit_window_get_tab_from_uri (GeditWindow *window,
+			       const gchar *uri)
+{
+	GList *tabs;
+	GList *l;
+	
+	g_return_val_if_fail (GEDIT_IS_WINDOW (window), NULL);
+	g_return_val_if_fail (uri != NULL, NULL);
+	
+	tabs = gtk_container_get_children (GTK_CONTAINER (window->priv->notebook));
+	
+	l = tabs;
+	while (l != NULL)
+	{
+		gchar *u;
+		GeditDocument *d;
+		GeditTab *t;
+		
+		t = GEDIT_TAB (l->data);
+		d = gedit_tab_get_document (t);
+
+		u = gedit_document_get_uri (d);
+
+		if ((u != NULL) && gnome_vfs_uris_match (uri, u))
+		{
+			g_free (u);
+			
+			g_list_free (tabs);
+			
+			return t;
+		}
+		
+		g_free (u);
+		
+		l = g_list_next (l);
+	}
+	
+	g_list_free (tabs);
+	
+	return NULL;
+}
+
